==> owncloud_7.0.4+dfsg.orig.tar.bz2: owncloud/core/l10n/bg_BG.php <==
<?php
$TRANSLATIONS = array(
"Sunday" => "Неделя",
"Monday" => "Понеделник",
"Tuesday" => "Вторник",
"Wednesday" => "Сряда",
"Thursday" => "Четвъртък",
"Friday" => "Петък",
"Saturday" => "Събота",
"January" => "Януари",
"February" => "Февруари",
"March" => "Март",
"April" => "Април",
"May" => "Май",
"June" => "Юни",
"July" => "Юли",
"August" => "Август",
"September" => "Септември",
"October" => "Октомври",
"November" => "Ноември",
"December" => "Декември",
"Settings" => "Настройки",
"Folder" => "Папка",
"Saving..." => "Записване...",
"seconds ago" => "преди секунди",
"_%n minute ago_::_%n minutes ago_" => array("",""),
"_%n hour ago_::_%n hours ago_" => array("",""),
"today" => "днес",
"yesterday" => "вчера",
"_%n day ago_::_%n days ago_" => array("",""),
"last month" => "последният месец",
"_%n month ago_::_%n months ago_" => array("",""),
"last year" => "последната година",
"years ago" => "последните години",
"Reset password" => "Нулиране на парола",
"Yes" => "Да",
"No" => "Не",
"Choose" => "Избери",
"Ok" => "Добре",
"_{count} file conflict_::_{count} file conflicts_" => array("",""),
"Cancel" => "Отказ",
"Shared" => "Споделено",
"Share" => "Споделяне",
"Error" => "Грешка",
"Error while sharing" => "Грешка при споделяне",
"Error while unsharing" => "Грепка докато се премахва споделянето",
"Error while changing permissions" => "Грешка при промяна на достъпност",
"Shared with you and the group {group} by {owner}" => "Споделено с тебе и група {group} от {owner}",
"Shared with you by {owner}" => "Споделено с тебе от {owner}",
"Password protect" => "Защитено с парола",
"Email link to person" => "Изпрати връзка до пощата на някои",
"Send" => "Изпрати",
"Set expiration date" => "Посочи дата на изтичане",
"Expiration date" => "Дата на изтичане",
"Share via email:" => "сподели по поща:",
"No people found" => "Не са открити хора",
"group" => "група",
"Resharing is not allowed" => "Допълнително споделяне не е разрешено",
"Shared in {item} with {user}" => "Споделено в {item} с {user}",
"Unshare" => "Премахни споделяне",
"can edit" => "може да променя",
"access control" => "контрол на достъпа",
"create" => "създаване",
"update" => "Обновяване",
"delete" => "Изтриване",
"Password protected" => "Защитено с парола",
"Error unsetting expiration date" => "Грешка при премахване на дата за изтичане",
"Error setting expiration date" => "Грепка при поставяне на дата за изтичане",
"Sending ..." => "Изпращам ...",
"Email sent" => "Пощата е изпратена",
"Warning" => "Внимание",
"The object type is not specified." => "Видът на обекта не е избран",
"Delete" => "Изтриване",
"Add" => "Добавяне",
"You will receive a link to reset your password via Email." => "Ще получите връзка за нулиране на паролата Ви.",
"Username" => "Потребител",
"New password" => "Нова парола",
"Personal" => "Лични",
"Users" => "Потребители",
"Apps" => "Приложения",
"Admin" => "Админ",
"Help" => "Помощ",
"Access forbidden" => "Достъпът е забранен",
"Cloud not found" => "облакът не намерен",
"Create an <strong>admin account</strong>" => "Създаване на <strong>админ профил</strong>",
"Password" => "Парола",
"Data folder" => "Директория за данни",
"Configure the database" => "Конфигуриране на базата",
"Database user" => "Потребител за базата",
"Database password" => "Парола за базата",
"Database name" => "Име на базата",
"Database host" => "Хост за базата",
"Finish setup" => "Завършване на настройките",
"Log out" => "Изход",
"remember" => "запомни",
"Log in" => "Вход",
"File not found" => "Файлът не е открит.",
"The specified document has not been found on the server." => "Избраният документ не е намерн на сървъра.",
"You can click here to return to %s." => "Можеш да натиснеш тук, за да се върнеш на %s",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.13~dfsg.orig.tar.bz2: owncloud/core/l10n/bg_BG.php <==
<?php
$TRANSLATIONS = array(
"Sunday" => "Неделя",
"Monday" => "Понеделник",
"Tuesday" => "Вторник",
"Wednesday" => "Сряда",
"Thursday" => "Четвъртък",
"Friday" => "Петък",
"Saturday" => "Събота",
"January" => "Януари",
"February" => "Февруари",
"March" => "Март",
"April" => "Април",
"May" => "Май",
"June" => "Юни",
"July" => "Юли",
"August" => "Август",
"September" => "Септември",
"October" => "Октомври",
"November" => "Ноември",
"December" => "Декември",
"Settings" => "Настройки",
"Folder" => "Папка",
"Saving..." => "Записване...",
"seconds ago" => "преди секунди",
"_%n minute ago_::_%n minutes ago_" => array("",""),
"_%n hour ago_::_%n hours ago_" => array("",""),
"today" => "днес",
"yesterday" => "вчера",
"_%n day ago_::_%n days ago_" => array("",""),
"last month" => "последният месец",
"_%n month ago_::_%n months ago_" => array("",""),
"last year" => "последната година",
"years ago" => "последните години",
"Reset password" => "Нулиране на парола",
"Yes" => "Да",
"No" => "Не",
"Choose" => "Избери",
"Ok" => "Добре",
"_{count} file conflict_::_{count} file conflicts_" => array("",""),
"Cancel" => "Отказ",
"Shared" => "Споделено",
"Share" => "Споделяне",
"Error" => "Грешка",
"Error while sharing" => "Грешка при споделяне",
"Error while unsharing" => "Грепка докато се премахва споделянето",
"Error while changing permissions" => "Грешка при промяна на достъпност",
"Shared with you and the group {group} by {owner}" => "Споделено с тебе и група {group} от {owner}",
"Shared with you by {owner}" => "Споделено с тебе от {owner}",
"Password protect" => "Защитено с парола",
"Email link to person" => "Изпрати връзка до пощата на някои",
"Send" => "Изпрати",
"Set expiration date" => "Посочи дата на изтичане",
"Expiration date" => "Дата на изтичане",
"Share via email:" => "сподели по поща:",
"No people found" => "Не са открити хора",
"group" => "група",
"Resharing is not allowed" => "Допълнително споделяне не е разрешено",
"Shared in {item} with {user}" => "Споделено в {item} с {user}",
"Unshare" => "Премахни споделяне",
"can edit" => "може да променя",
"access control" => "контрол на достъпа",
"create" => "създаване",
"update" => "Обновяване",
"delete" => "Изтриване",
"Password protected" => "Защитено с парола",
"Error unsetting expiration date" => "Грешка при премахване на дата за изтичане",
"Error setting expiration date" => "Грепка при поставяне на дата за изтичане",
"Sending ..." => "Изпращам ...",
"Email sent" => "Пощата е изпратена",
"Warning" => "Внимание",
"The object type is not specified." => "Видът на обекта не е избран",
"Delete" => "Изтриване",
"Add" => "Добавяне",
"You will receive a link to reset your password via Email." => "Ще получите връзка за нулиране на паролата Ви.",
"Username" => "Потребител",
"New password" => "Нова парола",
"Personal" => "Лични",
"Users" => "Потребители",
"Apps" => "Приложения",
"Admin" => "Админ",
"Help" => "Помощ",
"Access forbidden" => "Достъпът е забранен",
"Cloud not found" => "облакът не намерен",
"Create an <strong>admin account</strong>" => "Създаване на <strong>админ профил</strong>",
"Password" => "Парола",
"Data folder" => "Директория за данни",
"Configure the database" => "Конфигуриране на базата",
"Database user" => "Потребител за базата",
"Database password" => "Парола за базата",
"Database name" => "Име на базата",
"Database host" => "Хост за базата",
"Finish setup" => "Завършване на настройките",
"Log out" => "Изход",
"remember" => "запомни",
"Log in" => "Вход",
"File not found" => "Файлът не е открит.",
"The specified document has not been found on the server." => "Избраният документ не е намерн на сървъра.",
"You can click here to return to %s." => "Можеш да натиснеш тук, за да се върнеш на %s",
"To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" => "За да избегнеш таймаутове при по-големи инсталации, можеш да изпълниш следните команди в инсталанционната директория:",
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
